<?php

namespace Drupal\eca_vbo\Event;

use Drupal\Core\Action\ActionInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\eca\Event\ContentEntityEventInterface;
use Drupal\views\ViewExecutable;

/**
 * Dispatches when executing a "eca_vbo_execute" action.
 */
class VboExecuteEvent extends VboEventBase implements ContentEntityEventInterface {

  /**
   * The main entity of the Views row.
   *
   * @var \Drupal\Core\Entity\EntityInterface
   */
  protected EntityInterface $entity;

  /**
   * Contains view data and optionally batch operation context.
   *
   * @var array
   */
  public array $actionContext;

  /**
   * The action plugin configuration.
   *
   * @var array
   */
  public array $actionConfiguration;

  /**
   * The action plugin instance.
   *
   * @var mixed
   */
  protected ActionInterface $action;

  /**
   * Constructs a new ViewsBulkOperationsEvent object.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The main entity of the Views row.
   * @param \Drupal\views\ViewExecutable $view
   *   The executable view.
   * @param array &$action_context
   *   The context array passed from VBO to the action.
   * @param array &$action_configuration
   *   The action configuration.
   * @param \Drupal\Core\Action\ActionInterface $action
   *   The action plugin instance.
   */
  public function __construct(EntityInterface $entity, ViewExecutable $view, array &$action_context, array &$action_configuration, ActionInterface $action) {
    $this->entity = $entity;
    $this->view = $view;
    $this->actionContext = &$action_context;
    if (!isset($action_configuration['operation_name'])) {
      $action_configuration['operation_name'] = $action->getPluginDefinition()['operation_name'] ?? '';
    }
    $this->actionConfiguration = &$action_configuration;
    $this->operationName = &$action_configuration['operation_name'];
    $this->action = $action;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): EntityInterface {
    return $this->entity;
  }

  /**
   * Get the exeuctable view.
   *
   * @return \Drupal\views\ViewExecutable
   *   The executable view.
   */
  public function getView(): ViewExecutable {
    return $this->view;
  }

  /**
   * Get the action plugin instance.
   *
   * @return \Drupal\Core\Action\ActionInterface
   *   The action plugin instance.
   */
  public function getAction(): ActionInterface {
    return $this->action;
  }

}
